.. :changelog:

History
-------

0.5.0
-----

* dropping Python 2.7 support
* implemented ``forParentName``
* print taskid

0.4.0 (2018-08-07)
------------------

* you can paste tasks now, even as subtasks of a project. See help or docs!
* minor fixes

0.3.0 (2017-05-28)
------------------

* added 'action' property of tasks (e.g. url, phone, ...)
* switched from webbrowser.open to subprocess.call(['open', ...)

0.2.1 (2015-09-21)
------------------

* fixed classifier in setup.py
* fixed #3 - adding to lists works now.


0.2.0 (2015-09-20)
------------------

* first public release.


0.1.0 (unreleased)
------------------

* ADD: more commandline options implemented: repeat, due, dueTime, start
* ADD: docs


0.0.1 (2015-09-14)
------------------

* not released - pre alpha.
